CachedNetworkImage class

The dart:io implementation of ImageProvider.

Inheritance
Annotations

Constructors

CachedNetworkImage(String url, {double scale = 1.0, Map<String, String>? headers, Map<String, dynamic>? meta})
Creates an object that fetches the image at the given URL.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
headers Map<String, String>?
custom http headers
final
meta Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
The scale to place in the ImageInfo object of the image.
final
url String
Image url
final

Methods

createStream(ImageConfiguration configuration) ImageStream
Called by resolve to create the ImageStream it returns.
inherited
evict({ImageCache? cache, ImageConfiguration configuration = ImageConfiguration.empty}) Future<bool>
Evicts an entry from the image cache.
inherited
loadBuffer(CachedNetworkImage key, DecoderBufferCallback decode) ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
inherited
loadImage(CachedNetworkImage key, ImageDecoderCallback decode) ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obtainCacheStatus({required ImageConfiguration configuration, ImageErrorListener? handleError}) Future<ImageCacheStatus?>
Returns the cache location for the key that this ImageProvider creates.
inherited
obtainKey(ImageConfiguration configuration) Future<CachedNetworkImage>
Converts an ImageProvider's settings plus an ImageConfiguration to a key that describes the precise image to load.
override
resolve(ImageConfiguration configuration) ImageStream
Resolves this image provider using the given configuration, returning an ImageStream.
inherited
resolveStreamForKey(ImageConfiguration configuration, ImageStream stream, CachedNetworkImage key, ImageErrorListener handleError) → void
Called by resolve with the key returned by obtainKey.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override