CachedNetworkImage constructor
const
CachedNetworkImage(})
Creates an object that fetches the image at the given URL.
The arguments url and scale must not be null.
Implementation
const CachedNetworkImage(this.url, { this.scale = 1.0, this.headers, this.meta });