CacheManager class
CacheManager.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tempDirPath
→ Future<
String> -
no setter
Methods
-
getCached(
{required String id, required ReaderBuilder readerBuilder, DateTime? expireAt, CallbackOnProcess? onProcess}) → Future< Cached> -
getCached returns data use cache if
idis same, if no cache, usereaderBuilderto get new data, data save as file withext, data expire atexpireAt,onProcessis 0.0 ~ 1.0 -
getCachedFromUrl(
{required String url, DateTime? expireAt, CallbackOnProcess? onProcess, Map< String, String> ? headers, Map<String, dynamic> ? meta}) → Future<Cached> -
getCachedFromUrl returns data use cache or get from url,
data expire at
expireAt,onProcessis 0.0 ~ 1.0 -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited