CallbackOnProcess typedef
cumulativeBytesLoaded is The number of bytes that have been received across the wire thus far.
expectedTotalBytes The expected number of bytes that need to be received to finish loading the data.
Implementation
typedef CallbackOnProcess =void Function(int cumulativeBytesLoaded, int expectedTotalBytes);