CachedReaderImage constructor
const
CachedReaderImage(
- String id,
- ReaderBuilder readerBuilder, {
- double scale = 1.0,
Creates an object that fetches the image at the given URL.
The arguments id and scale must not be null.
Implementation
const CachedReaderImage(this.id, this.readerBuilder, { this.scale = 1.0});