manager library
Classes
- Cached
- CacheManager
- CacheManager.
- Reader
Typedefs
- CallbackOnProcess = void Function(int cumulativeBytesLoaded, int expectedTotalBytes)
-
cumulativeBytesLoadedis The number of bytes that have been received across the wire thus far.expectedTotalBytesThe expected number of bytes that need to be received to finish loading the data. - ReaderBuilder = Reader Function()