CacheManager class

CacheManager.

Constructors

CacheManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCached({required String id, required ReaderBuilder readerBuilder, String? ext, DateTime? expireAt, CallbackOnProcess? onProcess}) Future<Cached>
getCached returns data use cache if id is same, if no cache, use readerBuilder to get new data, data save as file with ext, data expire at expireAt, onProcess is 0.0 ~ 1.0
getCachedFromUrl({required String url, DateTime? expireAt, CallbackOnProcess? onProcess, Map<String, String>? headers}) Future<Cached>
getCachedFromUrl returns data use cache or get from url, data expire at expireAt, onProcess is 0.0 ~ 1.0
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited